@@ -3,11 +3,10 @@ import libraryArsein.encoder
 from libraryArsein.encoder import encoderjson
 import json
 from json import dumps, loads
-from libraryArsein.Errors import errors
 import time
 from time import sleep
 
-get_Errors = None
+get_Errors = False
 
 async def http(s,auth,js):
 	enc = encoderjson(auth)
@@ -17,9 +16,9 @@ async def http(s,auth,js):
 			if type(Post) == dict:
 				if "status_det" in Post.keys():
 					if Post.get("status_det") == 'INVALID_AUTH':
-						get_Errors = errors.chap_error
+						get_Errors = True
 					else:
-						get_Errors = None
+						get_Errors = False
 						return Post
 
 async def httpfiles(s,dade,head):
@@ -29,7 +28,7 @@ async def httpfiles(s,dade,head):
 			if type(Post) == dict:
 				if "status_det" in Post.keys():
 					if Post.get("status_det") == 'INVALID_AUTH':
-						get_Errors = errors.chap_error
+						get_Errors = True
 					else:
-						get_Errors = None
+						get_Errors = False
 						return Post
